| Title: | R package for mapping UK health data |
|---|---|
| Description: | A package to distribute and summarise on UK health data. |
| Authors: | Mike Page [cre], Matt Thomas [aut], Jenna Tan [aut], British Red Cross [cph] |
| Maintainer: | Mike Page <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.2.9000 |
| Built: | 2026-06-04 06:44:33 UTC |
| Source: | https://github.com/humaniverse/healthyr |
A dataset mapping proportion of A&E attendances attributed to Acute Trusts from Type 3 A&E Providers, including Minor Injury Units and Walk-in Centres
england_ae_acute_trust_attributionengland_ae_acute_trust_attribution
A data frame with 218 rows and 3 variables:
NHS Trust (organisational) code
NHS Trust (organisational) code - Acute Trusts only
Percentage of A&E attendances attributed to the Acute Trust
...
Crime severity score is based on sentencing data, community order and fines. Higher scores mean greater severity within an area.
england_crime_severityengland_crime_severity
A data frame containing 2 columns.
Local Authority code
Crime severity score (higher = more severe)
A dataset containing NHS Trust level critical care and general and acute bed availability information. This is taken from the urgent and emergency care daily situation reports. Bed numbers are daily figures averaged over the month.
england_critical_general_acute_bedsengland_critical_general_acute_beds
A data frame with 6,495 rows and 20 variables:
NHS Trust (organisational) code
Date
"G&A beds available"
"G&A beds occupied"
"G&A occupancy rate"
"Adult G&A beds available"
"Adult G&A beds occupied"
"Adult G&A occupancy rate"
"Paediatric G&A beds available"
"Paediatric G&A beds occupied"
"Paediatric G&A occupancy rate"
"Adult critical care beds available"
"Adult critical care beds occupied"
"Adult critical care occupancy rate"
"Paediatric intensive care beds available"
"Paediatric intensive care beds occupied"
"Paediatric intensive care occupancy rate"
"Neonatal intensive care beds available"
"Neonatal intensive care beds occupied"
"Neonatal intensive care occupancy rate"
...
A dataset containing LTLA data on numbers disabled under the Equality Act.
england_delayed_discharge_reasonsengland_delayed_discharge_reasons
A data frame with 45,106 rows and 5 variables:
NHS Trust name
NHS Trust code
Date in the format year-month-day
The reason for the delayed discharge
The number of delays
...
A dataset containing LTLA data on numbers disabled under the Equality Act.
england_disability_21england_disability_21
A data frame with 662 rows and 5 variables:
LTLA code
Total residents in the local authority
Disabled or Not disabled under the Equality Act
number of people
proportion of people
...
https://www.nomisweb.co.uk/sources/census_2021_bulk
A dataset containing overall health index scores for the English lower tier local authorities from 2015-2021.
england_health_indexengland_health_index
A data frame with 2,149 rows and 6 variables:
2021 Lower tier local authority code
Year
The overall health index score
Score for the Healthy People domain
Score for the Healthy Lives domain
Score for the Healthy Places domain
...
A dataset containing overall health index scores for the English Integrated Care Boards from 2015-2021.
england_health_index_icsengland_health_index_ics
A data frame with 294 rows and 7 variables:
2022 Integrated Care Board code
2022 Integrated Care Board name
Year
The overall health index score
Score for the Healthy People domain
Score for the Healthy Lives domain
Score for the Healthy Places domain
...
A dataset containing subdomain health index scores for the English Integrated Care Boards from 2015-2021.
A dataset containing underlying indicators for the ONS Health Index for English Integrated Care Boards from 2015-2021.
england_health_index_ics_indicators england_health_index_ics_indicatorsengland_health_index_ics_indicators england_health_index_ics_indicators
A data frame with 4,116 rows and 5 variables:
2022 Integrated Care Board code
2022 Integrated Care Board name
Year
The name of the subdomain
The value of the indicator
...
A data frame with 16,464 rows and 5 variables:
2022 Integrated Care Board code
2022 Integrated Care Board name
Year
The name of the indicator
The value of the indicator
...
A dataset containing underlying indicators for the ONS Health Index for English lower tier local authorities from 2015-2021.
england_health_index_indicatorsengland_health_index_indicators
A data frame with 120,344 rows and 4 variables:
2021 Lower tier local authority code
Year
The name of the indicator
The value of the indicator
...
A dataset containing subdomain health index scores for the English lower tier local authorities from 2015-2021.
england_health_index_subdomainsengland_health_index_subdomains
A data frame with 2,149 rows and 16 variables:
2021 Lower tier local authority code
Year
Difficulties in daily life - Health People domain
Mental health - Health People domain
Mortality - Health People domain
Personal well-being - Health People domain
Physical health conditions - Health People domain
Behavioural risk factors - Health Lives domain
Children and young people - Health Lives domain
Physiological risk factors - Health Lives domain
Protective measures - Health Lives domain
Access to green space - Health Places domain
Access to services - Health Places domain
Crime - Health Places domain
Economic and working conditions - Health Places domain
Living conditions - Health Places domain
...
A dataset containing statistics on households assessed as homeless and households in temporary accommodation, by Local Authority.
england_homelessnessengland_homelessness
A data frame with 3 variables:
Local Authority code
Households assessed as homeless per (000s)Households assessed as homeless per 1,000 households in the Local Authority
Households in temporary accommodation per 1,000Households in temporary accommodation per 1,000 households in the Local Authority
https://www.gov.uk/government/statistical-data-sets/live-tables-on-homelessness
A dataset containing England Accident and Emergency attendances and Emergency Admissions at Integrated Care Board level, by month
england_icb_accidents_emergencyengland_icb_accidents_emergency
A data frame with 1,680 rows and 8 variables:
Integrated Care Board code
The total number of patients in an A&E service seeking medical attention
The number of patients seeking medical attention that spend over 4 hours from arrival to admission, transfer or discharge
The total number of admissions to a hospital bed as an emergency
The number of patients seeking admission to a hospital bed as an emergency that spend over 4 hours from decision to admit to admission
The percentage of attendance that spend over 4 hours from arrival to admission, transfer of discharge
Date
The percentage of emergency admissions that spend over 4 hours from decision to admit to admission
...
A dataset containing NHS Integrated Care Board discharge data on how many patients do not meet criteria to reside each day.
england_icb_criteria_to_resideengland_icb_criteria_to_reside
A data frame with 51,727 rows and 3 variables:
Integrated Care Board code
Date
Number of patients who no longer meet the criteria to reside
...
A dataset containing NHS Integrated Care Board discharge data on how many patients were discharged each day. From June 2023 figures for discharged by 17:00 and between 17:01 and 23:59 were no longer released.
england_icb_discharged_patientsengland_icb_discharged_patients
A data frame with 51,727 rows and 5 variables:
Integrated Care Board code
Date
Number of patients discharged by 17:00
Number of patients discharged between 17:01 and 23:59
Total number of patients discharged
...
A dataset containing legal partnership status data at LTLA level
england_legal_partnership_21england_legal_partnership_21
A data frame with 5,627 rows and 5 variables:
LTLA code
Population in the LTLA
Type of legal partnership
Number of people
Percentage
https://www.nomisweb.co.uk/sources/census_2021_bulk
A dataset containing ICS/STP-level RTT data spanning from Apr 2020 to Feb 2025.
england_rtt_flow_stpengland_rtt_flow_stp
A data frame with 2,478 rows and 7 variables:
NHS code for the ICS/STP
Date
Year
Month
Number of pathways completed
Number of incomplete pathways
Number of new pathways
A dataset containing ICS/STP-level RTT data spanning from Jan 2019 to Feb 2025.
england_rtt_regionengland_rtt_region
A data frame with 11,676 rows and 7 variables:
Name of NHS England region
Date
Year
Month
Treatment function name
Total waiting > 18 weeks
Total waiting > 52 weeks
A dataset containing ICS/STP-level RTT data spanning from Apr 2020 to Feb 2025.
england_rtt_stpengland_rtt_stp
A data frame with 55,73 rows and 7 variables:
NHS code for the ICS/STP
Name of the ICS/STP
Date
Year
Month
Treatment function name
Total waiting > 18 weeks
Total waiting > 52 weeks
A dataset containing ICS/STP-level RTT data spanning from Jan 2019 to Feb 2025.
england_rtt_trustengland_rtt_trust
A data frame with 11,676 rows and 7 variables:
Code of NHS England trust
Name of NHS England trust
Date
Year
Month
Treatment function name
Total waiting > 18 weeks
Total waiting > 52 weeks
A dataset containing sexual orientation data at LTLA level
england_sexual_orientation_21england_sexual_orientation_21
A data frame with 1,655 rows and 5 variables:
LTLA code
Residents in the LTLA
Sexual orientation
Number of people
Percentage
https://www.nomisweb.co.uk/sources/census_2021_bulk
A dataset containing NHS Sub Integrated Care Board (formerly CCGs) data.
england_sicb_iaptengland_sicb_iapt
A data frame with 8,162 rows and 4 variables:
Sub Integrated Care Board code
Date
Name of the variable
Value of the variable
...
A dataset containing England Accident and Emergency attendances and Emergency Admissions at provider level, by month.
england_trust_accidents_emergencyengland_trust_accidents_emergency
A data frame with 7,895 rows and 8 variables:
NHS Trust (organisational) code
The total number of patients in an A&E service seeking medical attention
The number of patients seeking medical attention that spend over 4 hours from arrival to admission, transfer or discharge
The total number of admissions to a hospital bed as an emergency
The number of patients seeking admission to a hospital bed as an emergency that spend over 4 hours from decision to admit to admission
The percentage of attendance that spend over 4 hours from arrival to admission, transfer of discharge
Date
The percentage of emergency admissions that spend over 4 hours from decision to admit to admission
...
Data notes:
Due to a cyber-attack several sites have been unable to provide complete data since August 2022
Fourteen trusts are field testing new A&E performance standards and as a result are not required to report attendances over four hours from May 2019
A dataset containing NHS Trust level hopsital discharge data on how many patients do not meet criteria to reside each day.
england_trust_criteria_to_resideengland_trust_criteria_to_reside
A data frame with 149,482 rows and 3 variables:
NHS Trust (organisational) code
Date
Number of patients who no longer meet the criteria to reside
...
A dataset containing NHS Trust level hopsital discharge data on how many patients were discharged each day.
england_trust_discharged_patientsengland_trust_discharged_patients
A data frame with 149,482 rows and 5 variables:
NHS Trust (organisational) code
Date
Number of patients discharged by 17:00
Number of patients discharged between 17:01 and 23:59
Total number of patients discharged
...
A dataset containing NHS Trust level IAPT data.
england_trust_iaptengland_trust_iapt
A data frame with 5,082 rows and 4 variables:
NHS Trust (organisational) code
Date
Name of the variable
Value of the variable
...
A dataset containing the ratio of patients to GP workforce, by Local Authority
england_underdoctored_areasengland_underdoctored_areas
A data frame with 4 variables:
Local Authority code (2024)
Number of registered patients
Number of full-time equivalent GPs
Number of patients per GP
A dataset containing hospital statistics on bed availability, bed occupancy and inpatients data.
ni_bedsni_beds
A data frame with 13,327 rows and 14 variables:
Health and Social Care Trust code
Quarter ending date
Hospital name
Programme of care
Specialty
Total number of available beds
Average number of available beds
Total number of occupied beds
Average number of occupied beds
Total number of inpatients
Total number of day cases
Number of elective inpatients
Number of non-elective inpatients
Number of regular attenders
A dataset containing RTT data for Health & Social Care Trusts in NI.
ni_rtt_hsctni_rtt_hsct
A data frame with 2,706 rows and 7 variables:
Health & Social Care Trust name
Date
Year
Month
Specialty
Total waiting > 18 weeks
Total waiting > 52 weeks
Total waits
https://www.health-ni.gov.uk/topics/doh-statistics-and-research/hospital-waiting-times-statistics
A dataset containing the ratio of patients to GP workforce, by Local Authority
ni_underdoctored_areasni_underdoctored_areas
A data frame with 6 variables:
Local Authority code (2021)
Local Authority name (2021)
year
Number of registered patients
Number of GPs
Number of patients per GP
A dataset containing unpaid care data in Local Government Districts in NI from 2021 census.
ni_unpaid_care_21ni_unpaid_care_21
A data frame with 605 rows and 4 variables:
Local Government Districts name
Local Government Districts code
Age band and count/percentage of unpaid care hours
Value of the chosen variable
...
Emergency care waiting times for departments (hospitals) in Norther Ireland Health & Social Care Trusts.
ni_waiting_timesni_waiting_times
A data frame containing 8 columns.
Health and Social Care Trust code
Health and Social Care Trust name
Department name
Date
Total attendances
Attendances with waiting times under 4 hours
Attendances with waiting times between 4 and 12 hours
Attendances with waiting times over 12 hours
https://datavis.nisra.gov.uk/health/ni-emergency-care-waiting-times-data-oct-dec-24.html#table
A dataset containing Scotland hospital-level admission outcomes stratified by age group (from 2018-01 to 2025-02)
scotland_ae_admissionscotland_ae_admission
A data frame with 86,688 rows and 6 variables:
Hospital code
Hospital name
Date
Admission outcome
Age group
Total number of attendances falling into each category
...
A dataset of hospital-level A&E attendances and waiting times for Scotland (from 2007-07 to 2025-02).
scotland_ae_attendancescotland_ae_attendance
A data frame with 17,844 rows and 6 variables:
Hospital code
Hospital name
Date
Number of total attendances
Number of attendances lasting less than 4 hours
Number of attendances lasting more than 4 hours
...
Beds by Board of Treatment and Specialty, 2016-2024.
scotland_bedsscotland_beds
A data frame with 11,029 rows and 6 variables:
Scottish Health Board code
Date, representing the start of the quarter
Name of the specialty
Daily average number of available staffed beds
Daily average number of occupied beds
Percentage (%) of daily occupancy of beds
...
Scotland Health-Board level data for the number of people (per 1,000 population) supported by care at home (from 2018-Q1 to 2024-Q1).
scotland_care_at_homescotland_care_at_home
A data frame containing 800 rows and 4 columns.
2024 Lower tier local authority code
2024 Lower tier local authority name
Date
Number of people (per 1,000 population) receiving care at home
A dataset containing Delayed Discharge Bed Days by Scottish Health Board.
scotland_delayed_discharge_hbscotland_delayed_discharge_hb
A data frame with 24,750 rows and 6 variables:
Scottish Health Board code
Date
Age grouping is calculated as at the person's ready for discharge date
Reason for delay indicates the principal reason grouping for a person's delay at the end of the reporting month
The total number of delayed bed days
The average daily number of delayed beds is calculated by dividing the total number of delayed discharge bed days in the month by the number of days in the calendar month
...
https://www.opendata.nhs.scot/
A dataset containing Delayed Discharge Bed Days by Scottish Council Area
scotland_delayed_discharge_ltlascotland_delayed_discharge_ltla
A data frame with 56,100 rows and 6 variables:
Scottish Council Area code
Date
Age grouping is calculated as at the person's ready for discharge date
Reason for delay indicates the principal reason grouping for a person's delay at the end of the reporting month
The total number of delayed bed days
The average daily number of delayed beds is calculated by dividing the total number of delayed discharge bed days in the month by the number of days in the calendar month
...
https://www.opendata.nhs.scot/
A dataset containing statistics on households assessed as homeless and households in temporary accommodation, by Local Authority.
scotland_homelessnessscotland_homelessness
A data frame with 3 variables:
Local Authority code
Assessed as homeless or threatened with homelessness per 1,000Households assessed as homeless per 1,000 households in the Local Authority
Households in temporary accommodation per 1,000Households in temporary accommodation per 1,000 households in the Local Authority
https://www.gov.scot/collections/homelessness-statistics/
A dataset containing RTT data for Scotland.
scotland_rttscotland_rtt
A data frame with 153 rows and 5 variables:
Date
Year
Month
Total number waiting > 18 weeks
Percent waiting > 18 weeks
https://www.opendata.nhs.scot/
A dataset containing RTT data for Scottish Health Boards.
scotland_rtt_hbscotland_rtt_hb
A data frame with 2,370 rows and 7 variables:
Scottish Health Board code
Date
Year
Month
Specialty
Total number waiting > 18 weeks
Percent waiting > 18 weeks
https://www.opendata.nhs.scot/
A dataset containing the ratio of patients to GP workforce, by Local Authority
scotland_underdoctored_areasscotland_underdoctored_areas
A data frame with 4 variables:
Local Authority code (2021)
Number of full-time equivalent GPs
Number of registered patients
Number of patients per GP
A dataset containing performance against waiting times targets by hospital.
wales_ae_performancewales_ae_performance
A data frame with 73,863 rows and 5 variables:
Hospital code
Hospital or department name
Date
Performance measure
Performance target
Data
A dataset containing Welsh emergency ambulance calls and responses to red calls, by local health boards (HB) and month
wales_ambulance_waiting_timeswales_ambulance_waiting_times
A data frame with 288 rows and 9 variables:
Date
Local health board code
Name of local health board
Number of red calls
Number of red call resulting in an emergency response at the scene
Number of amber calls
Number of green calls
Number of red call resulting in an emergency response at the scene within 8 minutes
Percentage of emergency responses to red calls arriving at the scene within 8 minutes
...
Crime severity score is based on sentencing data, community order and fines. Higher scores mean greater severity within an area.
wales_crime_severitywales_crime_severity
A data frame containing 2 columns.
Local Authority code
Crime severity score (higher = more severe)
A dataset containing delayed discharge data stratified by local health board and the reason for delay.
wales_delayed_discharge_reasonswales_delayed_discharge_reasons
A data frame with 5,220 rows and 5 variables:
Health Board code
Health Board name
Date in the format year-month-day
The reason for the delayed discharge
The number of delays
...
A dataset containing LTLA data on numbers disabled under the Equality Act.
wales_disability_21wales_disability_21
A data frame:
LTLA code
Total residents in the local authority
Disabled or Not disabled under the Equality Act
number of people
proportion of people
...
https://www.nomisweb.co.uk/sources/census_2021_bulk
A dataset containing Welsh monthly NHS beds data by health board, measure, and specialty
wales_health_board_critical_general_acute_bedswales_health_board_critical_general_acute_beds
A data frame with 1,595 rows and 7 variables:
Date
Local health board code
Name of local health board
Name of specialism
Average number of daily beds available
Average number of daily beds occucpied
Bed occupancy rate
...
A dataset containing statistics on households assessed as homeless and households in temporary accommodation, by Local Authority.
wales_homelessnesswales_homelessness
A data frame with 3 variables:
Local Authority code
Homeless or threatened with homelessness per 1,000Households assessed as homeless per 1k households in the Local Authority
Households in temporary accommodation per 1,000Households in temporary accommodation per 1k households in the Local Authority
A dataset containing Welsh monthly NHS beds data by hospital site, measure, and specialty
wales_hospitals_critical_general_acute_bedswales_hospitals_critical_general_acute_beds
A data frame with 10,815 rows and 7 variables:
Date
Local health board code
Name of local health board
Name of specialism
Average number of daily beds available
Average number of daily beds occucpied
Bed occupancy rate
...
A dataset containing legal partnership status data at LTLA level
wales_legal_partnership_21wales_legal_partnership_21
A data frame:
LTLA code
Population in the LTLA
Type of legal partnership
Number of people
Percentage
https://www.nomisweb.co.uk/sources/census_2021_bulk
A dataset containing RTT data for Wales.
wales_rtt_lhbwales_rtt_lhb
A data frame with 2,212 rows and 7 variables:
Local Health Board code
Local Health Board name
Date
Stage of the treatment pathway
Total waiting > 18 weeks
Total waiting > 53 weeks
Total waiting
A dataset containing sexual orientation data at LTLA level
wales_sexual_orientation_21wales_sexual_orientation_21
A data frame:
LTLA code
Residents in the LTLA
Sexual orientation
Number of people
Percentage
https://www.nomisweb.co.uk/sources/census_2021_bulk
A dataset containing the ratio of patients to GP workforce, by Local Authority
wales_underdoctored_areaswales_underdoctored_areas
A data frame with 4 variables:
Local Authority code (2024)
Number of registered patients
Number of GPs
Number of patients per GP